/* File assert.h supplied with Escher C Verifier.
 * Use this file only if you are using the eCv preprocessor.
 * If you wish to use a compiler to preprocess C/C++ source instead, then
 *  you should use the standard include files supplied with that compiler.
 */

#if !defined(__ecv_assert_h_included__)
#define __ecv_assert_h_included__

#pragma ECV noverify

#if defined(__ECV__)

# if !defined(assert)
#  define assert(_x)	_ecv_assert(_x)
# endif

#else
# error "Missing macro definitions!. Use this include file only when running Escher C verifier."
#endif

#endif

/* End */
